gitops

package
v0.5.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DiffTreeFileList

func DiffTreeFileList(ctx context.Context, repoDir, commit1, commit2 string) ([]string, error)

DiffTreeFileList returns the list of files changed between two commits using git diff-tree. For initial commits (commit1 is empty), use --root mode. repoDir is the path to the git repository working tree; the command runs in that directory.

func DiffTreeFiles

func DiffTreeFiles(ctx context.Context, repoDir, commit1, commit2 string) (map[string]struct{}, error)

DiffTreeFiles returns the set of files changed between two commits using git diff-tree. For initial commits (commit1 is empty), use --root mode. repoDir is the path to the git repository working tree; the command runs in that directory. Returns a map of file paths for O(1) lookup.

Types

This section is empty.

Jump to