Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DiffTreeFileList ¶
DiffTreeFileList returns the list of files changed between two commits using git diff-tree. For initial commits (commit1 is empty), use --root mode. repoDir is the path to the git repository working tree; the command runs in that directory.
func DiffTreeFiles ¶
func DiffTreeFiles(ctx context.Context, repoDir, commit1, commit2 string) (map[string]struct{}, error)
DiffTreeFiles returns the set of files changed between two commits using git diff-tree. For initial commits (commit1 is empty), use --root mode. repoDir is the path to the git repository working tree; the command runs in that directory. Returns a map of file paths for O(1) lookup.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.